Scrapyd
=======

Scrapyd is an application for deploying and running Scrapy spiders. It
enables you to deploy (upload) your projects and control their spiders using a
JSON API.

Contents
--------
.. toctree::
   :maxdepth: 2

   overview
   install
   deploy
   api
   config
   contributing
   news
